Skip to contents

One-row summary of a model fit with convergence diagnostics.

Usage

# S3 method for class 'kb_fit'
glance(x, ..., rhat = 1.05, esr = 0.1)

Arguments

x

A kb_fit object.

...

Unused.

rhat

A number giving the maximum acceptable Rhat.

esr

A number giving the minimum acceptable effective sample rate (effective sample size divided by the number of draws).

Value

A one-row tibble with n, K, nchains, niters, nthin, ess (the minimum bulk effective sample size), rhat (the maximum Rhat), and converged.

Examples

glance(fit_weight_sim_nereo)
#> # A tibble: 1 × 8
#>       n     K nchains niters nthin   ess  rhat converged
#>   <int> <int>   <int>  <dbl> <int> <dbl> <dbl> <lgl>    
#> 1   234    10       2    400     1  201.  1.03 TRUE