Construct a Normal prior object for use in kb_priors_weight_nereo() and the
priors argument of the kb_fit_*() functions.
See also
Other priors:
kb_prior_exponential(),
kb_priors_weight_nereo()
Construct a Normal prior object for use in kb_priors_weight_nereo() and the
priors argument of the kb_fit_*() functions.
Other priors:
kb_prior_exponential(),
kb_priors_weight_nereo()