Whether a model fit has converged, from the Rhat and bulk effective sample rate of its parameters.
Usage
# S3 method for class 'kb_fit'
converged(x, ..., rhat = 1.05, esr = 0.1)Details
esr is the effective sample rate: the bulk effective sample size divided by
the number of draws. Convergence is assessed on the bulk effective sample size
only, not the tail. The defaults are rhat = 1.05 and esr = 0.1.
See also
Other generics:
augment.kb_fit(),
coef.kb_fit(),
fitted.kb_fit_weight(),
glance.kb_fit(),
kb_stancode(),
log_lik.kb_fit(),
posterior_epred.kb_fit_weight(),
posterior_linpred.kb_fit_weight(),
posterior_predict.kb_fit_weight(),
predict.kb_fit_weight(),
prior_summary.kb_fit(),
residuals.kb_fit_weight(),
samples(),
summary.kb_fit(),
tidy.kb_fit_weight()
Examples
converged(fit_weight_sim_nereo)
#> [1] TRUE