One-row summary of a model fit with convergence diagnostics.
Usage
# S3 method for class 'kb_fit'
glance(x, ..., rhat = 1.05, esr = 0.1)Value
A one-row tibble with n, K, nchains, niters, nthin, ess
(the minimum bulk effective sample size), rhat (the maximum Rhat), and
converged.
See also
Other generics:
augment.kb_fit(),
coef.kb_fit(),
converged.kb_fit(),
fitted.kb_fit_weight(),
kb_stancode(),
log_lik.kb_fit(),
posterior_epred.kb_fit_weight(),
posterior_linpred.kb_fit_weight(),
posterior_predict.kb_fit_weight(),
predict.kb_fit_weight(),
prior_summary.kb_fit(),
residuals.kb_fit_weight(),
samples(),
summary.kb_fit(),
tidy.kb_fit_weight()
Examples
glance(fit_weight_sim_nereo)
#> # A tibble: 1 × 8
#> n K nchains niters nthin ess rhat converged
#> <int> <int> <int> <dbl> <int> <dbl> <dbl> <lgl>
#> 1 234 10 2 400 1 201. 1.03 TRUE